@@ -29,7 +29,7 @@
 using namespace KGAPI2;
 using namespace KGAPI2::Blogger;
 
-class PageFetchJob::Private
+class Q_DECL_HIDDEN PageFetchJob::Private
 {
   public:
     Private(const QString &blogId,
