@@ -34,7 +34,7 @@
 
 using namespace KGAPI2;
 
-class CalendarCreateJob::Private
+class Q_DECL_HIDDEN CalendarCreateJob::Private
 {
   public:
     QueueHelper<CalendarPtr> calendars;
@@ -77,12 +77,14 @@ void CalendarCreateJob::start()
     const QByteArray rawData = CalendarService::calendarToJSON(calendar);
 
     QStringList headers;
-    Q_FOREACH(const QByteArray &str, request.rawHeaderList()) {
+    const auto rawHeaderList = request.rawHeaderList();
+    headers.reserve(rawHeaderList.size());
+    Q_FOREACH(const QByteArray &str, rawHeaderList) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
 
-    enqueueRequest(request, rawData, QLatin1String("application/json"));
+    enqueueRequest(request, rawData, QStringLiteral("application/json"));
 }
 
 ObjectsList CalendarCreateJob::handleReplyWithItems(const QNetworkReply *reply, const QByteArray& rawData)
