@@ -33,7 +33,7 @@
 
 using namespace KGAPI2;
 
-class CalendarFetchJob::Private
+class Q_DECL_HIDDEN CalendarFetchJob::Private
 {
   public:
     Private(CalendarFetchJob *parent);
@@ -59,7 +59,9 @@ QNetworkRequest CalendarFetchJob::Private::createRequest(const QUrl& url)
     request.setUrl(url);
 
     QStringList headers;
-    Q_FOREACH(const QByteArray &str, request.rawHeaderList()) {
+    const auto rawHeaderList = request.rawHeaderList();
+    headers.reserve(rawHeaderList.size());
+    Q_FOREACH(const QByteArray &str, rawHeaderList) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
