@@ -30,7 +30,7 @@
 
 using namespace KGAPI2;
 
-class EventDeleteJob::Private
+class Q_DECL_HIDDEN EventDeleteJob::Private
 {
   public:
     QueueHelper<QString> eventsIds;
@@ -91,7 +91,9 @@ void EventDeleteJob::start()
     request.setRawHeader("GData-Version", CalendarService::APIVersion().toLatin1());
 
     QStringList headers;
-    Q_FOREACH(const QByteArray &str, request.rawHeaderList()) {
+    auto rawHeaderList = request.rawHeaderList();
+    headers.reserve(rawHeaderList.size());
+    Q_FOREACH(const QByteArray &str, rawHeaderList) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
