@@ -33,7 +33,7 @@
 
 using namespace KGAPI2;
 
-class EventMoveJob::Private
+class Q_DECL_HIDDEN EventMoveJob::Private
 {
   public:
     Private(EventMoveJob *parent);
@@ -67,7 +67,9 @@ void EventMoveJob::Private::processNextEvent()
     request.setUrl(url);
 
     QStringList headers;
-    Q_FOREACH(const QByteArray &str, request.rawHeaderList()) {
+    auto rawHeaderList = request.rawHeaderList();
+    headers.reserve(rawHeaderList.size());
+    Q_FOREACH(const QByteArray &str, rawHeaderList) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
