@@ -32,7 +32,7 @@
 
 using namespace KGAPI2;
 
-class ContactsGroupFetchJob::Private
+class Q_DECL_HIDDEN ContactsGroupFetchJob::Private
 {
   public:
     Private(ContactsGroupFetchJob *parent);
@@ -57,7 +57,9 @@ QNetworkRequest ContactsGroupFetchJob::Private::createRequest(const QUrl& url)
     request.setUrl(url);
 
     QStringList headers;
-    Q_FOREACH(const QByteArray &str, request.rawHeaderList()) {
+    auto rawHeaderList = request.rawHeaderList();
+    headers.reserve(rawHeaderList.size());
+    Q_FOREACH(const QByteArray &str, rawHeaderList) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
