@@ -29,7 +29,7 @@
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
 
-class FileUntrashJob::Private
+class Q_DECL_HIDDEN FileUntrashJob::Private
 {
 };
 
