@@ -31,7 +31,7 @@
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
 
-class ParentReferenceDeleteJob::Private
+class Q_DECL_HIDDEN ParentReferenceDeleteJob::Private
 {
   public:
     QString fileId;
