@@ -32,7 +32,7 @@
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
 
-class ParentReferenceFetchJob::Private
+class Q_DECL_HIDDEN ParentReferenceFetchJob::Private
 {
   public:
     QString fileId;
