@@ -33,7 +33,7 @@
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
 
-class PermissionFetchJob::Private
+class Q_DECL_HIDDEN PermissionFetchJob::Private
 {
   public:
     QString fileId;
