@@ -32,7 +32,7 @@
 
 using namespace KGAPI2;
 
-class TaskFetchJob::Private
+class Q_DECL_HIDDEN TaskFetchJob::Private
 {
   public:
     Private(TaskFetchJob *parent);
@@ -71,7 +71,9 @@ QNetworkRequest TaskFetchJob::Private::createRequest(const QUrl& url)
     request.setUrl(url);
 
     QStringList headers;
-    Q_FOREACH(const QByteArray &str, request.rawHeaderList()) {
+    const auto rawHeaderList = request.rawHeaderList();
+    headers.reserve(rawHeaderList.size());
+    Q_FOREACH(const QByteArray &str, rawHeaderList) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
