@@ -31,7 +31,7 @@
 
 using namespace KGAPI2;
 
-class TaskListFetchJob::Private
+class Q_DECL_HIDDEN TaskListFetchJob::Private
 {
   public:
     Private(TaskListFetchJob *parent);
@@ -53,7 +53,9 @@ QNetworkRequest TaskListFetchJob::Private::createRequest(const QUrl& url)
     request.setUrl(url);
 
     QStringList headers;
-    Q_FOREACH(const QByteArray &str, request.rawHeaderList()) {
+    const auto rawHeaderList = request.rawHeaderList();
+    headers.reserve(rawHeaderList.size());
+    Q_FOREACH(const QByteArray &str, rawHeaderList) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
